/*
  Copyright 2008 CNRS
  Author: Florent Lamiraux
*/

#ifndef KPPCOMMANDCREATEGENOMTRAJ_H
#define KPPCOMMANDCREATEGENOMTRAJ_H

#include <map>
#include "KineoController/kppCommand.h"
#include "kppInterfaceDisplay/kppInterfaceDisplay.h"

KIT_PREDEF_CLASS(CkppCommandCreateGenoMTraj);
KIT_PREDEF_CLASS(CkwsPath);

/**
   \brief Create a trajectory related to a robot

   The GenoM poster of given name is read and a KineoWorks trajectory is built from poster data.
*/
class CkppCommandCreateGenoMTraj : public CkppCommand
{
public:
  enum EParameters
    {
      ROBOT,
      PARAMETER_COUNT
    };

  static CkppCommandCreateGenoMTrajShPtr create(CkppInterfaceDisplay *kpp);

  static CkppCommandCreateGenoMTrajShPtr createCopy(const CkppCommandCreateGenoMTrajConstShPtr& inCommand);

  virtual ~CkppCommandCreateGenoMTraj();

  virtual ktStatus doExecute();

  virtual bool isUndoable() const;

  virtual CkppCommandShPtr clone() const;
  
  virtual unsigned int countParameters() const;
  
  virtual CkppParameterConstShPtr parameter(unsigned int i_rank) const;

protected:

  CkppCommandCreateGenoMTraj(CkppInterfaceDisplay *inKppInterface);

  CkppCommandCreateGenoMTraj(const CkppCommandCreateGenoMTraj& inCommand);

  ktStatus init(const CkppCommandCreateGenoMTrajWkPtr& inWeakPtr);

private:

  CkppCommandCreateGenoMTrajWkPtr attWeakPtr;

  CkppInterfaceDisplay *attKppInterface;

};

#endif
