/*
  Copyright 2008 CNRS
  Author: Florent Lamiraux
*/

#ifndef KPPCOMMANDUPDATEGENOMTRAJ_H
#define KPPCOMMANDUPDATEGENOMTRAJ_H

#include <map>
#include "KineoController/kppCommand.h"
#include "kppInterfaceDisplay/kppInterfaceDisplay.h"

KIT_PREDEF_CLASS(CkppCommandUpdateGenoMTraj);
KIT_PREDEF_CLASS(CkwsPath);

/**
   \brief Update a trajectory related to a robot

   The GenoM poster of given name is read and a KineoWorks trajectory is built from poster data.
*/
class CkppCommandUpdateGenoMTraj : public CkppCommand
{
public:
  enum EParameters
    {
      PATH,
      PARAMETER_COUNT
    };

  static CkppCommandUpdateGenoMTrajShPtr create(CkppInterfaceDisplay *kpp);

  static CkppCommandUpdateGenoMTrajShPtr createCopy(const CkppCommandUpdateGenoMTrajConstShPtr& inCommand);

  virtual ~CkppCommandUpdateGenoMTraj();

  virtual ktStatus doExecute();

  virtual bool isUndoable() const;

  virtual CkppCommandShPtr clone() const;
  
  virtual unsigned int countParameters() const;
  
  virtual CkppParameterConstShPtr parameter(unsigned int i_rank) const;

protected:

  CkppCommandUpdateGenoMTraj(CkppInterfaceDisplay *inKppInterface);

  CkppCommandUpdateGenoMTraj(const CkppCommandUpdateGenoMTraj& inCommand);

  ktStatus init(const CkppCommandUpdateGenoMTrajWkPtr& inWeakPtr);

private:

  CkppCommandUpdateGenoMTrajWkPtr attWeakPtr;

  CkppInterfaceDisplay *attKppInterface;

};

#endif
