/*
 *  Copyright 2008 CNRS 
 *
 *  Author: Florent Lamiraux
 */

#ifndef KPPINTERFACEDISPLAY_H
#define KPPINTERFACEDISPLAY_H

#include "kppInterfaceWalk/kppInterfaceWalk.h"

KIT_PREDEF_CLASS(CkppInterfaceDisplay)
/**
  \brief Kpp interface aimed at displaying only.
 */

class CkppInterfaceDisplay : public CkppInterfaceWalk {
public:
  virtual ~CkppInterfaceDisplay();

  /**
     \brief Add a menu in menu bar.
  */
  virtual void getMenuUICommandLists(const CkppMainWindowUICommandFactoryConstShPtr& inCommandFactory,
				     std::vector< CkppUICommandListShPtr > & outMenuCommandListVector);

  /**
     \brief Create object and return shared pointer.
  */
  static CkppInterfaceDisplayShPtr create();

  /**
     \brief Add a poster name to the mapping
     \param inPath Shared pointer to the path
     \param name of the poster.
  */
  void addPosterNameToMapping(const CkwsPathShPtr& inPath, std::string inPosterName);

  /**
     \brief Get poster name related to a path shared pointer
     \param inPath shared pointer to a path
     \retval outPosterName name of the associated poster.

     \return KD_ERROR if path is not linked to any poster name.
  */
  ktStatus getPosterName(CkwsPathShPtr inPath, std::string& outPosterName);

  /**
     \brief Read Poster and copy trajectory in KineoWorks path
     \param inPath shared pointer to KineoWorks path to update.
     \note Poster name is retrived from private mapping.
  */
  ktStatus updatePathFromPoster(const CkwsPathShPtr& inPath);

protected:
  CkppInterfaceDisplay(ChppWalkPlanner* inHppPlanner);
  
  /**
     \brief Command to associate a GenoM poster with a KineoWorks path.
  */
  CkppUICommandShPtr attCommandCreateGenoMTraj;

  /**
     \brief Command to update a KineoWorks path by reading the associated GenoM poster.
  */
  CkppUICommandShPtr attCommandUpdateGenoMTraj;

private:

  /**
     \brief Mapping between path shared pointer and poster name
  */
  std::map <CkwsPathShPtr, std::string> attPosterNameMap;

};

// function use to compile the KPP license
extern "C" KPP_ADDON_API int initializeModule(CkppModuleInterfaceShPtr& outModuleInterface);

#endif
